@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 import os
+import sys
 import requests
-import shutil
 import zipfile
 from prompt_user import prompt
 
@@ -14,7 +14,17 @@ def download_file(url):
     '''
     response = requests.get(url, stream = True)
     with open('subtitle.zip', 'wb') as out_file:
-        shutil.copyfileobj(response.raw, out_file)
+        fsrc = response.raw
+        size = response.headers.get("content-length")
+        length = 16*1024
+        while True:
+            buf = fsrc.read(length)
+            if not buf:
+                break
+            out_file.write(buf)
+            sys.stdout.write("Downloaded " + str(os.path.getsize('subtitle.zip')/1024) + "kb of " + str(int(size)/1024) + " kb\r")
+            sys.stdout.flush()
+        print "\nDownload complete\nExtracting"
     del response
     try:
         zipfile.ZipFile.extractall(zipfile.ZipFile('subtitle.zip'))
